@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "flymake-ansible-lint" "1.0.5"
+(define-package "flymake-ansible-lint" "20250920.1926"
   "A Flymake backend for ansible-lint."
-  '((emacs "27.1"))
+  '((emacs "26.1"))
   :url "https://github.com/jamescherti/flymake-ansible-lint.el"
-  :commit "c5375aea83586e1ae97e6c2fa74ea61cf44d98f4"
-  :revdesc "1.0.5-0-gc5375aea8358"
+  :commit "fcd15eafd96afa35f4b3d52f320d949d110bf573"
+  :revdesc "fcd15eafd96a"
   :keywords '("tools"))
